@@ -23,7 +23,7 @@ async def http_get_raw(url, headers={}):
     session = _client_session
     async with session.get(url, ssl=False, headers=headers) as r:
         if not (r.status >= 200 and r.status < 300):
-            raise CommError(f'{url} {method} returns {r.status}')
+            raise CommError(f'{url} raw get request returns {r.status}')
         return await r.read()
 
 
