@@ -6,6 +6,7 @@ from . import aiorequests
 from urllib.parse import urlencode
 from osrm.engine.api.fbresult import FBResult as FBI
 
+
 def decode_str(obj):
     if not obj:
         return None
@@ -14,11 +15,18 @@ def decode_str(obj):
     if type(obj) == str:
         return obj
 
+
 class OutputFormat(str, Enum):
     json = 'json'
     flatbuffers = 'flatbuffers'
 
 
+class Geometry(str, Enum):
+    polyline = 'polyline'
+    polyline6 = 'polyline6'
+    geojson = 'geojson'
+
+
 class Code(str, Enum):
     Ok = "Ok"
     InvalidUrl = "InvalidUrl"
@@ -55,29 +63,28 @@ class NearestResponse(Response):
 
     @classmethod
     def from_fb(cls, buf: bytes):
-        fb = FBI.FBResult.GetRootAsFBResult(buf,0) 
-        code = decode_str(fb.Code())
+        fb = FBI.FBResult.GetRootAsFBResult(buf, 0)
         if fb.Error():
+            code = decode_str(fb.Code().Code())
             return cls(code=code)
+        code = Code.Ok
         waypoints = []
         wl = fb.WaypointsLength()
-        for i in range(0,wl):
+        for i in range(0, wl):
             wfb = fb.Waypoints(i)
             loc = wfb.Location()
             nodes = wfb.Nodes()
-            wp= Waypoint(
-                hint= decode_str(wfb.Hint()),
-                location=(loc.Longtitude(),loc.Latitude()),
-                name= decode_str(wfb.Name()),
+            wp = WayPoint(
+                hint=decode_str(wfb.Hint()),
+                location=(loc.Longtitude(), loc.Latitude()),
+                name=decode_str(wfb.Name()),
                 distance=wfb.Distance(),
             )
             if nodes:
-                wp.nodes = [nodes.First(),nodes.Second()]
+                wp.nodes = [nodes.First(), nodes.Second()]
             waypoints.append(wp)
 
-        return cls(code = code, waypoints= waypoints)
-
-
+        return cls(code=code, waypoints=waypoints)
 
 
 class Leg(BaseModel):
@@ -95,30 +102,31 @@ class Route(BaseModel):
 class RouteResponse(Response):
     routes: List[Route] = []
     waypoints: List[WayPoint] = []
-    
+
     @classmethod
     def from_dict(cls, dct: Dict):
         return cls(**dct)
 
     @classmethod
     def from_fb(cls, buf: bytes):
-        fb = FBI.FBResult.GetRootAsFBResult(buf,0) 
-        code = decode_str(fb.Code())
+        fb = FBI.FBResult.GetRootAsFBResult(buf, 0)
         if fb.Error():
+            code = decode_str(fb.Code().Code())
             return cls(code=code)
+        code = Code.Ok
         routes = []
         waypoints = []
         rl = fb.RoutesLength()
-        for i in range(0,rl):
+        for i in range(0, rl):
             rfb = fb.Routes(i)
-            route = Route(duration = rfb.Duration(), distance=rfb.Distance(), geometry=decode_str(rfb.Polyline()))
+            route = Route(duration=rfb.Duration(), distance=rfb.Distance(), geometry=decode_str(rfb.Polyline()))
             ll = rfb.LegsLength()
             for j in range(0, ll):
                 lfb = rfb.Legs(j)
-                leg = Leg(duration = lfb.Duration(), distance = lfb.Distance())
+                leg = Leg(duration=lfb.Duration(), distance=lfb.Distance())
                 route.legs.append(leg)
             routes.append(route)
-        return cls(code = code, routes = routes, waypoints = waypoints)
+        return cls(code=code, routes=routes, waypoints=waypoints)
 
 
 class POI(BaseModel):
@@ -138,15 +146,15 @@ class TableResponse(Response):
 
     @classmethod
     def from_fb(cls, buf: bytes):
-        fb = FBI.FBResult.GetRootAsFBResult(buf,0) 
-        code = decode_str(fb.Code())
+        fb = FBI.FBResult.GetRootAsFBResult(buf, 0)
         if fb.Error():
+            code = decode_str(fb.Code().Code())
             return cls(code=code)
+        code = Code.Ok
         tfb = fb.Table()
         durations = [[y for y in x] for x in tfb.DurationsAsNumpy()]
         distances = [[y for y in x] for x in tfb.DistancesAsNumpy()]
-        return cls(code = code, duration= durations, distances=distances) 
-
+        return cls(code=code, duration=durations, distances=distances)
 
 
 class TracePoint(BaseModel):
@@ -164,26 +172,26 @@ class MatchResponse(Response):
 
     @classmethod
     def from_fb(cls, buf: bytes):
-        fb = FBI.FBResult.GetRootAsFBResult(buf,0) 
-        code = decode_str(fb.Code())
+        fb = FBI.FBResult.GetRootAsFBResult(buf, 0)
         if fb.Error():
+            code = decode_str(fb.Code().Code())
             return cls(code=code)
+        code = Code.Ok
         matchings = []
         tracepoints = []
         rl = fb.RoutesLength()
-        for i in range(0,rl):
+        for i in range(0, rl):
             rfb = fb.Routes(i)
-            route = Route(duration = rfb.Duration(), distance=rfb.Distance())
+            route = Route(duration=rfb.Duration(), distance=rfb.Distance())
             matchings.append(route)
         wl = fb.WaypointsLength()
-        for i in range(0,wl):
+        for i in range(0, wl):
             wfb = fb.Waypoints(i)
             loc = wfb.Location()
-            tp= TracePoint(matchings_index = wfb.MatchingsIndex(), location=(loc.Longtitude(),loc.Latitude()))
+            tp = TracePoint(matchings_index=wfb.MatchingsIndex(), location=(loc.Longtitude(), loc.Latitude()))
             tracepoints.append(tp)
 
-        return cls(code = code, matchings= matchings, tracepoints= tracepoints)
-
+        return cls(code=code, matchings=matchings, tracepoints=tracepoints)
 
 
 class Gaps(str, Enum):
@@ -193,27 +201,26 @@ class Gaps(str, Enum):
     split = "split"
     ignore = "ignore"
 
-def parse_google_coords(inp: str):
-    return [LatLng(lat=float(t[0]),lng=float(t[1])) for t in [pair.split(',') for pair in [pairs for pairs in inp.split('|')] ]]
 
+def parse_google_coords(inp: str):
+    return [LatLng(lat=float(t[0]), lng=float(t[1])) for t in [pair.split(',') for pair in [pairs for pairs in inp.split('|')]]]
 
 
 class API:
 
     def __init__(self, base_url: str):
         self.base_url = base_url
-        self.valid_formats = ['json','flatbuffers']
+        self.valid_formats = ['json', 'flatbuffers']
 
-    async def _call(self, url:str,output_format:OutputFormat, responseCls):
+    async def _call(self, url: str, output_format: OutputFormat, responseCls):
         if output_format not in self.valid_formats:
-            raise ValueErorr(f'invalid output format: {self.output_format}')
+            raise ValueError(f'invalid output format: {self.output_format}')
         if output_format == 'json':
             return responseCls.from_dict(await aiorequests.http_get_json(url))
         elif output_format == 'flatbuffers':
             return responseCls.from_fb(await aiorequests.http_get_raw(url))
 
-
-    async def nearest(self, loc: LatLng,output_format: OutputFormat, radius: Optional[float] = None, bearing: Optional[float] = None) -> NearestResponse:
+    async def nearest(self, loc: LatLng, output_format: OutputFormat, radius: Optional[float] = None, bearing: Optional[float] = None) -> NearestResponse:
         url = f'{self.base_url}/nearest/v1/driving/{loc.lng},{loc.lat}.{output_format}'
         params = {}
         if radius is not None:
@@ -229,7 +236,7 @@ class API:
         destinations_param = ';'.join(destinations)
         url = f'{self.base_url}/table/v1/driving/{coords_param}.{output_format}?sources={sources_param}&destinations={destinations_param}&annotations=duration,distance'
         return await self._call(url, output_format, TableResponse)
-        
+
     async def match(self, coords: List[LatLng], output_format: OutputFormat,
                     timestamps: Optional[List[int]] = None,
                     radiuses: Optional[List[float]] = None,
@@ -249,8 +256,7 @@ class API:
         url += "?" + urlencode(params)
         return await self._call(url, output_format, MatchResponse)
 
-    async def route(self, coords: List[LatLng], output_format: OutputFormat) -> RouteResponse:
+    async def route(self, coords: List[LatLng], output_format: OutputFormat, geometry: Geometry = Geometry.polyline) -> RouteResponse:
         coords_param = ';'.join([f'{c.lng},{c.lat}' for c in coords])
-        url = f'{self.base_url}/route/v1/driving/{coords_param}.{output_format}?overview=full'
+        url = f'{self.base_url}/route/v1/driving/{coords_param}.{output_format}?overview=full&geometries={geometry}'
         return await self._call(url, output_format, RouteResponse)
-
